==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DInterfaceInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DInterfaceInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34ba7078330e82b6 soot_dava_internal_javaRep_DInterfaceInvokeExpr
// @dep_class 176f59a86ee1a2b8 soot_grimp_internal_GInterfaceInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 9a153470fbee82fc soot_jimple_internal_AbstractInterfaceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GInterfaceInvokeExpr

#include "soot/grimp/internal/GInterfaceInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$vmethods	soot_jimple_internal_AbstractInterfaceInvokeExpr;
	_jc_soot_grimp_internal_GInterfaceInvokeExpr$vmethods	soot_grimp_internal_GInterfaceInvokeExpr;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
    _jc_soot_grimp_internal_GInterfaceInvokeExpr$sub_refs	soot_grimp_internal_GInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_grimp_internal_GInterfaceInvokeExpr$sub_nonrefs	soot_grimp_internal_GInterfaceInvokeExpr;
    _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DInterfaceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DInterfaceInvokeExpr.h <==
// public class soot.dava.internal.javaRep.DInterfaceInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34ba7078330e82b6 soot_dava_internal_javaRep_DInterfaceInvokeExpr
// @dep_class 176f59a86ee1a2b8 soot_grimp_internal_GInterfaceInvokeExpr
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 9a153470fbee82fc soot_jimple_internal_AbstractInterfaceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr

// header file dependencies
// @dep_header soot_grimp_internal_GInterfaceInvokeExpr

#include "soot/grimp/internal/GInterfaceInvokeExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_
#define _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$_init$737b9105a0ba7cab(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
	_jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$vmethods	soot_jimple_internal_AbstractInterfaceInvokeExpr;
	_jc_soot_grimp_internal_GInterfaceInvokeExpr$vmethods	soot_grimp_internal_GInterfaceInvokeExpr;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vmethods	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs {
    _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_refs	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
    _jc_soot_grimp_internal_GInterfaceInvokeExpr$sub_refs	soot_grimp_internal_GInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInterfaceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInterfaceInvokeExpr;
    _jc_soot_grimp_internal_GInterfaceInvokeExpr$sub_nonrefs	soot_grimp_internal_GInterfaceInvokeExpr;
    _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$sub_nonrefs	soot_dava_internal_javaRep_DInterfaceInvokeExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$object {
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$vtype _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DInterfaceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DInterfaceInvokeExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DInterfaceInvokeExpr_H_ */
